TableData class

Inheritance

Constructors

TableData(Map _param, BuildContext _context, DataModel _dataModel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isRowCountApproximate → bool
Called to establish if rowCount is a precise number or might be an over-estimate. If this returns true (i.e. the count is approximate), and then later the exact number becomes available, then call notifyListeners.
no setteroverride
rowCount → int
Called to obtain the number of rows to tell the user are available.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedRowCount → int
Called to obtain the number of rows that are currently selected.
no setteroverride

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
getRow(int index) → DataRow
Called to obtain the data about a particular row.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited